%bcond_with bootstrap

%global srcname JCTools

Name:           jctools
Version:        4.0.2
Release:        %mkrel 1
Group:          Development/Java
Summary:        Java Concurrency Tools for the JVM
License:        Apache-2.0

URL:            https://github.com/JCTools/JCTools
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz

BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(com.google.guava:guava-testlib)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-all)
%endif

%description
This project aims to offer some concurrent data structures
currently missing from the JDK:

° SPSC/MPSC/SPMC/MPMC Bounded lock free queues
° SPSC/MPSC Unbounded lock free queues
° Alternative interfaces for queues
° Offheap concurrent ring buffer for ITC/IPC purposes
° Single Writer Map/Set implementations
° Low contention stats counters
° Executor


%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.


%prep
%setup -q -n %{srcname}-%{version}

# drop some failure-prone tests (race conditions?)
rm jctools-core/src/test/java/org/jctools/queues/MpqSanityTestMpscCompound.java

# set correct version in all pom.xml files
%pom_xpath_set pom:project/pom:version %{version}
%pom_xpath_set pom:parent/pom:version %{version} jctools-{build,core,channels,experimental}

# remove plugins unnecessary for RPM builds
%pom_remove_plugin :coveralls-maven-plugin jctools-core
%pom_remove_plugin :jacoco-maven-plugin jctools-core
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-source-plugin jctools-core
%pom_remove_plugin :maven-javadoc-plugin jctools-core

# remove tests with additional kotlin dependencies
rm -r jctools-core/src/test/java/org/jctools/maps/linearizability_test/

# disable unused modules with unavailable dependencies
%pom_disable_module jctools-benchmarks
%pom_disable_module jctools-concurrency-test

# incompatible with Java 11 and unused in fedora:
# https://github.com/JCTools/JCTools/issues/254
%pom_disable_module jctools-channels
%pom_disable_module jctools-experimental

%pom_disable_module jctools-build
%pom_remove_plugin :exec-maven-plugin jctools-core

# do not install internal build tools
%mvn_package :jctools-build __noinstall

# do not install unused parent POM
%mvn_package :jctools-parent __noinstall


%build
# Tests time out in Koji
%mvn_build -s -f


%install
%mvn_install


%files -f .mfiles-jctools-core
%doc README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Fri May 24 2024 ns80 <ns80> 4.0.2-1.mga10
+ Revision: 2067136
- new version 4.0.2 for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 4.0.1-1.mga10
+ Revision: 1986470
- Resolves rhbz#2092837 jctools-4.0.1 is available
- Build with default JDK 17

* Fri Dec 09 2022 daviddavid <daviddavid> 3.3.0-2.mga9
+ Revision: 1919862
- Build with OpenJDK 8
- Disable jctools-build module

* Sun Sep 11 2022 neoclust <neoclust> 3.3.0-1.mga9
+ Revision: 1886962
- New version  3.3.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Feb 26 2021 daviddavid <daviddavid> 3.2.0-1.mga9
+ Revision: 1691878
- Update to version 3.2.0

* Mon Sep 07 2020 daviddavid <daviddavid> 3.1.0-1.mga8
+ Revision: 1623163
- Update to latest upstream version 3.1.0
- Obsolete sub-packages that cannot be built on JDK 11
- Patch for javaparser API changes

* Sun Feb 16 2020 umeabot <umeabot> 2.1.2-4.mga8
+ Revision: 1536149
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 2.1.2-3.mga8
+ Revision: 1453403
- Disable failure-prone unreliable test

* Thu Jul 18 2019 daviddavid <daviddavid> 2.1.2-2.mga8
+ Revision: 1422562
- fix UTF-8 characters in description

* Thu Jul 18 2019 daviddavid <daviddavid> 2.1.2-1.mga8
+ Revision: 1422384
- Update to latest upstream release 2.1.2

* Thu Sep 20 2018 umeabot <umeabot> 2.0.2-2.mga7
+ Revision: 1278918
- Mageia 7 Mass Rebuild

* Tue Aug 15 2017 daviddavid <daviddavid> 2.0.2-1.mga7
+ Revision: 1140713
- Update to 2.0.2

* Fri Aug 11 2017 daviddavid <daviddavid> 1.2.1-1.mga7
+ Revision: 1139820
- update to 1.2.1 (sync with fedora 27)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.1-0.3.alpha.1.mga6
+ Revision: 977112
- sync package jctools with fedora
- imported package jctools


* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-0.3.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-0.2.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 19 2015 gil cattaneo <puntogil@libero.it> 1.1-0.1.alpha
- initial rpm
